_prereq: Represents system packages required for installing SageMath from source
================================================================================

Description
-----------

This script package represents the minimal requirements (system packages)
for installing SageMath from source.
